from _pytest.monkeypatch import MonkeyPatch
from rasax.community import config
from rasax.community.services.feature_service import FeatureService


def test_get_default_feature(feature_service: FeatureService, monkeypatch: MonkeyPatch):
    test_feature = {
        "name": "show the save button for the model config",
        "enabled": False,
    }
    monkeypatch.setattr(config, "DEFAULT_FEATURE_FLAGS", [test_feature])
    features = feature_service.features()

    assert len(features) == 1
    assert features[0] == test_feature


def test_set_feature(feature_service: FeatureService, monkeypatch: MonkeyPatch):
    test_feature = {
        "name": "show the save button for the model config",
        "enabled": True,
    }
    feature_service.set_feature(test_feature)
    feature_service.commit()

    test_feature_default = test_feature.copy()
    test_feature_default["enabled"] = False

    monkeypatch.setattr(config, "DEFAULT_FEATURE_FLAGS", [test_feature_default])
    features = feature_service.features()

    assert len(features) == 1
    assert features[0] == test_feature


def test_set_non_existing_feature(feature_service: FeatureService):
    test_feature = {"name": "print money", "enabled": False}

    feature_service.set_feature(test_feature)

    assert feature_service.features() == config.DEFAULT_FEATURE_FLAGS
